@@ -16,7 +16,7 @@ Usage::
     session_client: IoTDataPlaneClient = session.client("iot-data")
     ```
 """
-from mypy_boto3_iot_data.client import IoTDataPlaneClient, IoTDataPlaneClient as Client
+from mypy_boto3_iot_data.client import IoTDataPlaneClient as Client, IoTDataPlaneClient
 
 
 __all__ = ("Client", "IoTDataPlaneClient")
